@@ -1,23 +1,20 @@
-use cocoa::base::id;
+use cocoa::appkit::NSApp;
 use cocoa::foundation::NSInteger;
 use objc::runtime::{BOOL, NO, YES};
 
 #[inline(always)]
 unsafe fn with_activation<T>(mut f: impl FnMut() -> T) -> T {
-    let app: id = msg_send![class!(NSApplication), sharedApplication];
+    let app = NSApp();
     let policy: NSInteger = msg_send![app, activationPolicy];
 
     if policy == 2 {
-        let _: () = msg_send![app, setActivationPolicy:1];
+        let () = msg_send![app, setActivationPolicy:1];
+        let ret = f();
+        let () = msg_send![app, setActivationPolicy:2];
+        ret
+    } else {
+        f()
     }
-
-    let ret = f();
-
-    if policy == 2 {
-        let _: () = msg_send![app, setActivationPolicy:2];
-    }
-
-    ret
 }
 
 #[inline(always)]
@@ -34,9 +31,6 @@ pub use url::*;
 mod bundle;
 pub use bundle::*;
 
-mod alert;
-pub use alert::*;
-
 mod image;
 pub use image::*;
 
@@ -58,6 +52,15 @@ pub use text_field::*;
 mod pop_up_button;
 pub use pop_up_button::*;
 
+mod window;
+pub use window::*;
+
+mod panel;
+pub use panel::*;
+
+mod alert;
+pub use alert::*;
+
 mod open_panel;
 pub use open_panel::*;
 
